summaryrefslogtreecommitdiffstats
path: root/webkit/glue/resource_loader_bridge.h
diff options
context:
space:
mode:
Diffstat (limited to 'webkit/glue/resource_loader_bridge.h')
-rw-r--r--webkit/glue/resource_loader_bridge.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/webkit/glue/resource_loader_bridge.h b/webkit/glue/resource_loader_bridge.h
index df55897..e1a5a99 100644
--- a/webkit/glue/resource_loader_bridge.h
+++ b/webkit/glue/resource_loader_bridge.h
@@ -141,9 +141,9 @@ struct ResourceResponseInfo {
// Content length if available. -1 if not available
int64 content_length;
- // Length of the raw data transferred over the network. In case there is no
- // data, contains -1.
- int64 raw_data_length;
+ // Length of the encoded data transferred over the network. In case there is
+ // no data, contains -1.
+ int64 encoded_data_length;
// The appcache this response was loaded from, or kNoCacheId.
int64 appcache_id;
@@ -305,12 +305,12 @@ class ResourceLoaderBridge {
// Called when a chunk of response data is available. This method may
// be called multiple times or not at all if an error occurs.
// The raw_data_length is the length of the raw data transferred over the
// network, which could be different from data length (e.g. for gzipped
// content), or -1 if if unknown.
virtual void OnReceivedData(const char* data,
int data_length,
- int raw_data_length) = 0;
+ int encoded_data_length) = 0;
// Called when metadata generated by the renderer is retrieved from the
// cache. This method may be called zero or one times.
@@ -305,12 +305,12 @@ class ResourceLoaderBridge {
// Called when a chunk of response data is available. This method may
// be called multiple times or not at all if an error occurs.
- // The raw_data_length is the length of the raw data transferred over the
- // network, which could be different from data length (e.g. for gzipped
- // content), or -1 if if unknown.
+ // The encoded_data_length is the length of the encoded data transferred
+ // over the network, which could be different from data length (e.g. for
+ // gzipped content), or -1 if if unknown.
virtual void OnReceivedData(const char* data,
int data_length,